div.callout {
  border-left: 3px solid #BBB;
  background-color: #EEE;
  padding: 12px 12px 12px 32px;
  display: block;
  position: relative;
  margin-bottom: 0.75em;
}

div.callout.info {
   border-left-color: #0288D1;
   background-color: #d3efff;
   color: #015380;
 }

div.callout.success {
   border-left-color: #52A256;
   background-color: #e7f3e7;
   color: #376c39;
 }

div.callout.warning {
   border-left-color: #e27b41;
   background-color: #faeae0;
   color: #b6531c;
 }

div.callout.danger {
   border-left-color: #E84F4F;
   background-color: #fce8e8;
   color: #b91818;
 }