@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("settings") { @import "settings"; }

/**
 * Flexible images (videos see #4896)
 *
 * @see http://webdesignerwall.com/tutorials/responsive-design-with-css3-media-queries
 */
img {
  max-width:100%;
  height:auto;
}
.ie7 img {
  -ms-interpolation-mode:bicubic;
}
.ie8 img {
  width:auto; /* see #5789 */
}

/**
 * Hide invisible elements
 */
.invisible {
  border:0;
  clip:rect(0 0 0 0);
  height:1px;
  margin:-1px;
  overflow:hidden;
  padding:0;
  position:absolute;
  width:1px;
}

/**
 * Margins, Paddings, Alignment, Text transforms and decorations
 */
.tt_u {
  text-transform: uppercase;
  letter-spacing: 0.1em;
}

.td_u {
  border-bottom: 1px $color-text solid;
}

.ta_left {
  text-align: left;
}

.ta_right {
  text-align: right;
}

.ta_center {
  text-align: center;
}
.fl_left {
  float: left;
}
.fl_right {
  float: right;
}

.fw_light {
  font-weight: 300;
}
.fw_normal {
  font-weight: 400;
}
.fw_semi-bold {
  font-weight: 600;
}
.fw_bold {
  font-weight: 700;
}

/* --- CE SPACING --- */
.spc_default {
  margin-bottom: $gutter-default*2;
}
.spc_paragraph {
  margin-bottom: 1.5rem;
}
.spc_boxed {
  margin-bottom: 20px;
}
.pad_default {
  padding: $gutter-default 0;
}