@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("framework") { @import "framework"; }

html, body {
  font: $font-size-default/$line-height-default $font-family;

  @include for-mobile {
    font-size: 18px;
  }
}

h1, h2, h3, h4, h5, h6, p, pre, blockquote, table, ol, ul, form {
  margin-bottom: $gutter-default;
}

body {
  font-weight: $font-weight-default;
  color: $color-text;
}

strong,
b {
  font-weight: 700;
}

a {
  text-decoration: none;
  color: $color-link;
  @include transition(color 0.2s ease);

  &:hover {
    color: mix($color-link,#000,80%);
  }
}

p {
  margin-bottom: 1.5em;

  &:last-child {
    margin-bottom: 0;
  }
}
h1,h2,h3,h4,h5,h6 {
  @include headline();
  margin: 0 0 0.5em;
  line-height: 1.15;

  em,i {
    font-style: normal;
    color: $color-text-invert;
  }

  &:last-child {
    margin-bottom: 0;
  }
}

h1, h2 {
  font-size: font-size(50px);
  text-align: center;
}

h3 {
  font-size: font-size(35px);
}

h4,h5 {
  color: $color-text;
  font-weight: 400;
  font-size: font-size(32px);

  &.fw_normal {
    font-weight: 400;
  }
}

@include for-tablet {
  h1, h2 {
    font-size: font-size(40px);
  }

  h3 {
    font-size: font-size(30px);
  }

  h4,h5 {
    font-size: font-size(25px);
  }
}
@include for-mobile {
  h1, h2 {
    font-size: font-size(35px);
  }

  h3 {
    font-size: font-size(28px);
  }

  h4,h5 {
    font-size: font-size(24px);
  }
}

.ff_h {
  font-family: $font-family-handwriting;
  font-weight: 400;
  text-transform: none;
  letter-spacing: normal;
}

.ff_a {
  font-family: $font-family-alternate;
  letter-spacing: 0.1em;
  text-transform: none;
}

.fs_small {
  font-size: font-size(16px);
}

.fs_mini {
  font-size: font-size(12px);
}